==> kibana-7.9.1.tgz: kibana/src/plugins/vis_type_timeseries/server/saved_objects/tsvb_telemetry.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.tsvbTelemetrySavedObjectType = void 0;

var _lodash = require("lodash");

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const resetCount = doc => ({ ...doc,
  attributes: { ...doc.attributes,
    failedRequests: 0
  }
});

const tsvbTelemetrySavedObjectType = {
  name: 'tsvb-validation-telemetry',
  hidden: false,
  namespaceType: 'agnostic',
  mappings: {
    properties: {
      failedRequests: {
        type: 'long'
      }
    }
  },
  migrations: {
    '7.7.0': (0, _lodash.flow)(resetCount),
    '7.8.0': (0, _lodash.flow)(resetCount),
    '7.9.0': (0, _lodash.flow)(resetCount)
  }
};
exports.tsvbTelemetrySavedObjectType = tsvbTelemetrySavedObjectType;

==> kibana-7.10.0.tgz: kibana/src/plugins/vis_type_timeseries/server/saved_objects/tsvb_telemetry.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.tsvbTelemetrySavedObjectType = void 0;

var _lodash = require("lodash");

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const resetCount = doc => ({ ...doc,
  attributes: { ...doc.attributes,
    failedRequests: 0
  }
});

const tsvbTelemetrySavedObjectType = {
  name: 'tsvb-validation-telemetry',
  hidden: false,
  namespaceType: 'agnostic',
  mappings: {
    properties: {
      failedRequests: {
        type: 'long'
      }
    }
  },
  migrations: {
    '7.7.0': (0, _lodash.flow)(resetCount),
    '7.8.0': (0, _lodash.flow)(resetCount),
    '7.9.0': (0, _lodash.flow)(resetCount),
    '7.10.0': (0, _lodash.flow)(resetCount)
  }
};
exports.tsvbTelemetrySavedObjectType = tsvbTelemetrySavedObjectType;
